import {Component, Prop, h} from '@stencil/core';
import {HeadingVarians, FooterLinkItemColor} from '../../../utils/utils';

@Component({
  tag: 'hy-footer-link-item',
  styleUrl: 'hy-footer-link-item.scss',
  shadow: false,
})
export class HyFooterLinkItem {
  @Prop() label: string;
  @Prop() url: string;
  @Prop() mainLink: boolean = false;
  @Prop() items: Array<any>;
  @Prop() color: FooterLinkItemColor = FooterLinkItemColor.black;
  @Prop() isMobile: boolean;

  render() {
    const containerClassAttributes = [
      'hy-footer-link-item--container',
      this.items && 'hy-footer-link-item__has-children',
    ].join(' ');
    const classAttributes = [
      'hy-footer-link-item',
      this.mainLink && 'hy-footer-link-item__main',
      `hy-footer-link-item__color-${this.color}`,
    ].join(' ');

    if (this.items) {
      if (this.isMobile) {
        return (
          <div class={containerClassAttributes}>
            {this.items.map((item) => {
              return (
                <a
                  class={`hy-footer-link-item hy-footer-link-item__color-${this.color}`}
                  href={item.url}
                  style={{color: this.color}}
                >
                  {item.label}
                  <hy-icon class={'hy-footer-link-item__icon'} icon={'hy-icon-arrow-right'} size={16} />
                </a>
              );
            })}
          </div>
        );
      } else {
        return (
          <div class={containerClassAttributes}>
            <hy-heading class={classAttributes} heading={HeadingVarians.h3}>
              <a class={'hy-footer-link-item__link'} href={this.url} style={{color: this.color}}>
                {this.label}
              </a>
            </hy-heading>
            {this.items.map((item) => {
              return (
                <a
                  class={`hy-footer-link-item hy-footer-link-item__color-${this.color}`}
                  href={item.url}
                  style={{color: this.color}}
                >
                  {item.label}
                  <hy-icon class={'hy-footer-link-item__icon'} icon={'hy-icon-arrow-right'} size={16} />
                </a>
              );
            })}
          </div>
        );
      }
    } else {
      return (
        <a class={classAttributes} href={this.url} style={{color: this.color}}>
          {this.label}
          <hy-icon class={'hy-footer-link-item__icon'} icon={'hy-icon-arrow-right'} size={16} />
        </a>
      );
    }
  }
}
